Learn R Programming

iBMQ (version 1.12.0)

gene: Gene expression from whole eye tissue from n = 68 BXD RIS mice.

Description

This dataset comprises the profiles of mRNA abundance in whole eye tissue from n = 68 BXD RIS mice, as measured using Affymetrix M430 2.0 microarrays. To ease calculation and facilitate comparisons, we will use a set of G = 1000 probes

Usage

data(gene)

Arguments

Format

The format is: Formal class 'ExpressionSet' [package "Biobase"]

This example uses data generated by Williams and Lu, as available from the Gene Networkwebsite (genenetwork.com). This dataset comprises the profiles of mRNA abundance in whole eye tissue from n = 68 BXD RIS mice, as measured using Affymetrix M430 2.0 microarrays. To ease calculation and facilitate comparisons, we will use a set of G = 1000 probes

Examples

Run this code
data(gene)

Run the code above in your browser using DataLab