Learn R Programming

iBMQ (version 1.12.0)

genotype.liver: A set of 290 SNPs from 60 F2 mice.

Description

A set of 290 single nucleotide polymorphic markers (SNPs) from 60 F2 mice.

Arguments

Format

The format is: Formal class 'SnpSet' [package "Biobase"]

This F2 cross data set containing genotypic and phenotypic information for 60 mice was obtained from the lab of Alan Attie at the University of Wisconsin-Madison. These data are also available at GEO (accession number GSE3330). Only the 5000 most variable expression traits out of 45,265 transcripts from the liver were used for the current example.

Examples

Run this code
data(genotype.liver)

Run the code above in your browser using DataLab