Learn R Programming

iBMQ (version 1.12.0)

map.liver: SNP position data frame

Description

A data frame specifying the genomic locations of each SNP with following columns: SNP name, chromosome number, SNP location (in base pair).

Arguments

Format

A data frame with 290 observations with the following columns: SNP name, chromosome number, SNP location (in base pair).

This F2 cross data set containing genotypic and phenotypic information for 60 mice was obtained from the lab of Alan Attie at the University of Wisconsin-Madison. These data are also available at GEO (accession number GSE3330). Only the 5000 most variable expression traits out of 45,265 transcripts from the liver were used for the current example.

Examples

Run this code
data(map.liver)

Run the code above in your browser using DataLab