Learn R Programming

iBMQ (version 1.12.0)

phenotype.liver: Gene expression from liver tissue from n = 60 F2 mice.

Description

Gene expression of 5000 probe from liver tissue from n = 60 F2 mice.

Arguments

Format

The format is: Formal class 'ExpressionSet' [package "Biobase"]

This F2 cross data set containing genotypic and phenotypic information for 60 mice was obtained from the lab of Alan Attie Lab at the University of Wisconsin-Madison. These data are also available at GEO (accession number GSE3330). Only the 5000 most variable expression traits out of 45,265 transcripts from the liver were used for the current example.

Examples

Run this code
data(phenotype.liver)

Run the code above in your browser using DataLab