Learn R Programming

iBMQ (version 1.12.0)

snppos: SNP position data frame

Description

A data frame specifying the genomic locations of each SNP with following columns: SNP name, chromosome number, SNP location (in base pair).

Usage

data(snppos)

Arguments

Format

A data frame with 1700 observations with the following columns: SNP name, chromosome number, SNP location (in base pair).

This example uses data generated by Williams and Lu, as available from the Gene Network website (genenetwork.com).

Examples

Run this code
data(snppos)

Run the code above in your browser using DataLab