Format
A data frame with 1700 observations with the following columns: SNP name, chromosome number, SNP location (in base pair).Source
This example uses data generated by Williams and Lu, as available from the Gene Network website (genenetwork.com).